@@ -1,3 +1,5 @@
+from imblearn.over_sampling import RandomOverSampler
+
 
 # Function for data normalization
 def normalize(col, df, method):
@@ -10,21 +12,25 @@ def normalize(col, df, method):
 
     return df
 
-"""
+
 # Function to manage oversampling method
 def oversampling(df, method, ycol):
-
     if method == "random":
         df = randomOverSampling(df, ycol)
     elif method == "smote":
         df = SMOTE(df, ycol)
     return df
 
+
 # Perform random oversampling of the dataframe
 def randomOverSampling(df, ycol):
+    oversampler = RandomOverSampler(sampling_strategy='minority')
+    X = df.loc[:, df.columns != ycol]
+    Y = df[ycol]
+
     return df
 
+
 # Perform SMOTE in the dataframe
 def SMOTE(df, ycol):
     return df
-"""
\ No newline at end of file
