@@ -13,10 +13,11 @@ def readJson(dataFile, jsonFile):
     json_opener = open(jsonFile)
     json_file = json.load(json_opener)
     input_data_type = json_file['input_format']
-    checkJSONFormat(json_file)
     # Get the data in pandas df format
     original_dataDF = readFile(input_data_type, dataFile, json_file['separator'], json_file['header'])
     original_dataDF.columns = original_dataDF.columns.str.strip().str.replace('"', '')
+    checkJSONFormat(json_file, original_dataDF.columns.values, list(original_dataDF.select_dtypes(
+        include=['bool']).columns))
     for col in original_dataDF:
         if original_dataDF.dtypes[col] == "object":
             original_dataDF[col] = original_dataDF[col].str.replace('"', '')
@@ -51,7 +52,7 @@ def readJson(dataFile, jsonFile):
 
     # OverSampling
     #if json_file['balance_data'] == "yes":
-    #    dataDF = dataModeling.oversampling(dataDF, json_file['balance_params']['balance_method'],
+    #    dataDF = oversampling(dataDF, json_file['balance_params']['balance_method'],
     #                                       json_file['balance_params']['y_col'])
 
 
